Aggregates genotypes within annotation categories.
Aggregator(
anno,
geno,
drop_empty = TRUE,
indicator = FALSE,
method = "none",
min_mac = 0,
weights = c(1, 2, 3)
)(n x L) Numeric matrix without weighting, (n x 1) numeric matrix with weighting.
(snps x 1) annotation vector with integer values in 1 through the number of annotation categories L.
(n x snps) genotype matrix.
Drop empty columns? Default: TRUE.
Convert raw counts to indicators? Default: FALSE.
Method for aggregating across categories: ("none", "max", "sum"). Default: "none".
Minimum minor allele count for inclusion. Default: 0.
(L x 1) vector of annotation category weights. Note that the
number of annotation categories L is inferred from the length of weights.
Ensure the length of the weights vector matches the total number of
annotation categories.
The weights essentially scales the minor allele count in the lth
category by weights[l].